Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVincent Petry <pvince81@owncloud.com>2016-04-27 16:24:28 +0300
committerVincent Petry <pvince81@owncloud.com>2016-05-20 18:56:02 +0300
commit09b3883d9ceae77793e524209090f2e36ab61260 (patch)
treea85b527783e3df487900b43ae9fb86018d695750 /lib/public/SystemTag
parent8343cfb64b8297035987bc4980ec72015c8e1a04 (diff)
Updated canUser* functions in SystemTagManager to accept objects
Diffstat (limited to 'lib/public/SystemTag')
-rw-r--r--lib/public/SystemTag/ISystemTagManager.php23
1 files changed, 9 insertions, 14 deletions
diff --git a/lib/public/SystemTag/ISystemTagManager.php b/lib/public/SystemTag/ISystemTagManager.php
index 7fb0c21436c..283ca63e4f6 100644
--- a/lib/public/SystemTag/ISystemTagManager.php
+++ b/lib/public/SystemTag/ISystemTagManager.php
@@ -22,6 +22,9 @@
namespace OCP\SystemTag;
+use OCP\IUser;
+use OCP\SystemTag\ISystemTag;
+
/**
* Public interface to access and manage system-wide tags.
*
@@ -117,33 +120,25 @@ interface ISystemTagManager {
* Checks whether the given user is allowed to assign/unassign the tag with the
* given id.
*
* @param string|\OCP\SystemTag\ISystemTag $tag tag id or system tag
* @param string $userId user id
*
* @return true if the user is allowed to assign/unassign the tag, false otherwise
*
- * @throws \OCP\SystemTag\TagNotFoundException if tag with the given id does not exist
- * @throws \OCP\UserNotFoundException if the given user id does not exist
- * @throws \InvalidArgumentException if the tag id is invalid (string instead of integer, etc.)
- *
* @since 9.1.0
*/
- public function canUserAssignTag($tag, $userId);
+ public function canUserAssignTag(ISystemTag $tag, IUser $user);
/**
* Checks whether the given user is allowed to see the tag with the given id.
*
* @param string|\OCP\SystemTag\ISystemTag $tag tag id or system tag
* @param string $userId user id
*
* @return true if the user is allowed to assign/unassign the tag, false otherwise
*
- * @throws \OCP\SystemTag\TagNotFoundException if tag with the given id does not exist
- * @throws \OCP\UserNotFoundException if the given user id does not exist
- * @throws \InvalidArgumentException if the tag id is invalid (string instead of integer, etc.)
- *
* @since 9.1.0
*/
- public function canUserSeeTag($tag, $userId);
+ public function canUserSeeTag(ISystemTag $tag, IUser $userId);
}
@@ -117,33 +120,25 @@ interface ISystemTagManager {
* given id.
*
- * @param string|\OCP\SystemTag\ISystemTag $tag tag id or system tag
- * @param string $userId user id
+ * @param ISystemTag $tag tag to check permission for
+ * @param IUser $user user to check permission for
*
* @return true if the user is allowed to assign/unassign the tag, false otherwise
@@ -117,33 +120,25 @@ interface ISystemTagManager {
* Checks whether the given user is allowed to see the tag with the given id.
*
- * @param string|\OCP\SystemTag\ISystemTag $tag tag id or system tag
- * @param string $userId user id
+ * @param ISystemTag $tag tag to check permission for
+ * @param IUser $user user to check permission for
*
* @return true if the user is allowed to assign/unassign the tag, false otherwise